==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-postsearch.js <==
//User agents not recognized by presearch and a-z search
//This here have to be anywhere in the identification line
dispMUA.arDispMUAAllocation["postsearch"] =
{
  ".apache.org)" : [ "apache.png" , "http://www.apache.org/" ] ,
  "/pinoymail.com" : [ "pinoymail_com.png" , "http://www.pinoymail.com/" ] ,
  "; cisco" : [ "cisco.png" , "http://www.cisco.com/" ] ,
  "by gecip sas" : [ "gecip.png" ] ,
  "communigate" : [ "communigate.png" ] ,
  "egroupware" : [ "egroupware.png" ] ,
  "emacs" : [ "emacs.png" ] ,
  "entourage" : [ "ms_entourage.png" , "http://www.microsoft.com/" ] ,
  "freebit.com" : [ "freebit.png" ] ,
  "global mail exchange" : [ "gmx.png" , "http://www.gmx.com/" ] ,
  "global message exchange" : [ "gmx.png" , "http://www.gmx.net/" ] ,
  "gmane.org" : [ "gmane.png" ] ,
  "gossamer" : [ "gossamer.png" ] ,
  "groupwise" : [ "groupwise.png" ] ,
  "libero.it" : [ "libero_it.png" , "http://liberomail.libero.it/" ] ,
  "m5mailer.com" : [ "m5_mailer.png" , "http://www.mach5.com/products/mailer/" ] ,
  "mozilla" : [ "mozilla.png" , "http://www.mozilla.org/" ] ,
  "pochta.ru" : [ "pochta_ru.png" , "http://www.pochta.ru/" ] ,
  "polarbar" : [ "polarbar.png" ] ,
  "registered ak-mail" : [ "ak_mail.png" ] ,
  "rosecitysoftware.com" : [ "courier_rose.png" , "http://www.rosecitysoftware.com/courier/" ] ,
  "techtarget.com" : [ "targetmail_techtarget.png" ] ,
  "webmail for roxen" : [ "roxen.png" ] ,
  "www.chello.at" : [ "chello_at.png" , "http://www.chello.at/" ] ,
  "www.xp2.de" : [ "crosspoint_xp2.png" , "http://xp2.de/" ] ,
}

==> icedove-dispmua_1.6.3.orig.tar.gz: icedove-dispmua-1.6.3/chrome/content/data-postsearch.js <==
//User agents not recognized by presearch and a-z search
//This here have to be anywhere in the identification line
dispMUA.arDispMUAAllocation["postsearch"] =
{
  ".apache.org)" : [ "apache.png" , "http://www.apache.org/" ] ,
  "/pinoymail.com" : [ "pinoymail_com.png" , "http://www.pinoymail.com/" ] ,
  "communigate(r) pro" : [ "communigatepro.png" , "http://www.communigate.com/CommuniGatePro/" ] ,
  "egroupware" : [ "egroupware.png" ] ,
  "entourage" : [ "ms_entourage.png" , "http://www.microsoft.com/" ] ,
  "global mail exchange" : [ "gmx.png" , "http://www.gmx.com/" ] ,
  "global message exchange" : [ "gmx.png" , "http://www.gmx.net/" ] ,
  "http://gmane.org/" : [ "gmane.png" , "http://gmane.org/" ] ,
  "www.gossamer-threads.com" : [ "gossamer.png" , "http://www.gossamer-threads.com/scripts/webmail/" ] ,
  "libero.it" : [ "libero_it.png" , "http://liberomail.libero.it/" ] ,
  "m5mailer.com" : [ "m5_mailer.png" , "http://www.mach5.com/products/mailer/" ] ,
  "pochta.ru" : [ "pochta_ru.png" , "http://www.pochta.ru/" ] ,
  "registered ak-mail" : [ "ak-mail.png" , "http://www.akmail.com/" ] ,
  "www.chello.at" : [ "chello_at.png" , "http://www.chello.at/" ] ,
  "www.xp2.de" : [ "crosspoint_xp2.png" , "http://xp2.de/" ] ,
  ".mail.yahoo.com" : [ "yahoo.png" , "http://mail.yahoo.com/" ] ,
  "-nl emm v" : [ "intershop.png" , "http://www.intershop.de/" ] ,
  "zentraldata" : [ "zentraldata.png" , "http://www.zentraldata.de/" ] ,
  "emacs/" : [ "emacs.png" , "http://www.gnu.org/software/emacs/" ] ,
  "mozilla" : [ "mozilla.png" , "http://www.mozilla.org/" ] ,
}
